package com.ruoyi.interfaces.service.impl;

import java.util.List;
import java.util.UUID;

import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.interfaces.domain.MdModelAcl;
import com.ruoyi.interfaces.mapper.MdModelAclMapper;
import com.ruoyi.interfaces.service.IMdModelAclService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 模型访问控制Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class MdModelAclServiceImpl implements IMdModelAclService
{
    @Autowired
    private MdModelAclMapper mdModelAclMapper;

    /**
     * 查询模型访问控制
     * 
     * @param aclid 模型访问控制主键
     * @return 模型访问控制
     */
    @Override
    public MdModelAcl selectMdModelAclByAclid(String aclid)
    {
        return mdModelAclMapper.selectMdModelAclByAclid(aclid);
    }

    /**
     * 查询模型访问控制列表
     * 
     * @param mdModelAcl 模型访问控制
     * @return 模型访问控制
     */
    @Override
    public List<MdModelAcl> selectMdModelAclList(MdModelAcl mdModelAcl)
    {
        return mdModelAclMapper.selectMdModelAclList(mdModelAcl);
    }

    /**
     * 新增模型访问控制
     * 
     * @param mdModelAcl 模型访问控制
     * @return 结果
     */
    @Override
    public int insertMdModelAcl(MdModelAcl mdModelAcl)
    {
        mdModelAcl.setAclid(IdUtils.fastUUID());
        return mdModelAclMapper.insertMdModelAcl(mdModelAcl);
    }

    /**
     * 修改模型访问控制
     * 
     * @param mdModelAcl 模型访问控制
     * @return 结果
     */
    @Override
    public int updateMdModelAcl(MdModelAcl mdModelAcl)
    {
        return mdModelAclMapper.updateMdModelAcl(mdModelAcl);
    }

    /**
     * 批量删除模型访问控制
     * 
     * @param aclids 需要删除的模型访问控制主键
     * @return 结果
     */
    @Override
    public int deleteMdModelAclByAclids(String[] aclids)
    {
        return mdModelAclMapper.deleteMdModelAclByAclids(aclids);
    }

    /**
     * 删除模型访问控制信息
     * 
     * @param aclid 模型访问控制主键
     * @return 结果
     */
    @Override
    public int deleteMdModelAclByAclid(String aclid)
    {
        return mdModelAclMapper.deleteMdModelAclByAclid(aclid);
    }
}